CameraManagerImpl class

Opens camera experiences and maps captured files back into Ensemble state.

Inheritance
  • Object
  • CameraManager
  • CameraManagerImpl

Constructors

CameraManagerImpl()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

bespokeCamera(BuildContext context, ShowCameraAction cameraAction, ScopeManager? scopeManager) Future<void>
Opens Ensemble's custom camera widget.
buildLoadingWidget(ScopeManager? scopeManager, ShowCameraAction cameraAction) Widget?
Builds the optional camera loading widget.
buildOverlayWidget(ScopeManager? scopeManager, ShowCameraAction cameraAction) Widget?
Builds the optional camera overlay widget.
convertXFile(XFile element) Future<File?>
Converts an image picker file to Ensemble file data.
defaultCamera(BuildContext context, ShowCameraAction cameraAction, ScopeManager? scopeManager) Future<void>
Opens the platform default camera picker.
hasPermission() Future<bool?>
Checks whether a camera is available and accessible.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openCamera(BuildContext context, ShowCameraAction cameraAction, ScopeManager? scopeManager) Future<void>
Opens the configured camera flow.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited