JsObject class

Constructors

JsObject(dynamic constructor, [List? arguments])

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

callMethod(String method, [List? args]) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](String property) → dynamic
operator []=(String property, dynamic value) → void

Static Methods

jsify(Object object) → dynamic