CameraState class
Constructors
Properties
- accelerometerSub ↔ StreamSubscription?
-
getter/setter pair
-
cameras
↔ List<
CameraDescription> -
getter/setter pair
- context → BuildContext
-
The location in the tree where this widget builds.
no setterinherited
- currentIndex ↔ int
-
getter/setter pair
- currentModeIndex ↔ int
-
getter/setter pair
-
flashIcons
→ List<
IconData> -
final
-
flashModes
→ List<
FlashMode> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasPermission ↔ bool
-
getter/setter pair
- iconColor ↔ Color
-
getter/setter pair
- iconSize ↔ double
-
getter/setter pair
- imagePicker → ImagePicker
-
final
- isCropping ↔ bool
-
getter/setter pair
- isFrontCamera ↔ bool
-
getter/setter pair
- isFullScreen ↔ bool
-
getter/setter pair
- isLoading ↔ bool
-
getter/setter pair
- isRecording ↔ bool
-
getter/setter pair
- isTimerRunning ↔ bool
-
getter/setter pair
- locator ↔ GeolocatorPlatform
-
getter/setter pair
-
modes
↔ List<
CameraMode> -
getter/setter pair
- mounted → bool
-
Whether this State object is currently in a tree.
no setterinherited
- pageController ↔ PageController
-
getter/setter pair
-
phoneAngle
↔ ValueNotifier<
double?> -
getter/setter pair
-
phoneSpeed
↔ ValueNotifier<
double?> -
getter/setter pair
- positionSub ↔ StreamSubscription?
-
getter/setter pair
- previewPageController → PageController
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scopeManager ↔ ScopeManager?
-
getter/setter pairinherited
- seconds ↔ int
-
getter/setter pair
- showPreviewPage ↔ bool
-
getter/setter pair
- timer ↔ Timer?
-
getter/setter pair
- widget → Camera
-
The current configuration.
no setterinherited
Methods
-
activate(
) → void -
Called when this object is reinserted into the tree after having been
removed via deactivate.
inherited
-
appbar(
{required void backArrowAction()?, required void deleteButtonAction()?, }) → Widget -
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
inherited
-
buildWidget(
BuildContext context) → Widget -
build your widget here
override
-
cameraButton(
) → Widget -
cameraView(
) → Widget -
canCapture(
) → bool -
capture(
) → void -
changeState(
) → void -
inherited
-
deactivate(
) → void -
Called when this object is removed from the tree.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
deleteImages(
) → void -
didChangeAccessibilityFeatures(
) → void -
Called when the system changes the set of currently active accessibility
features.
inherited
-
didChangeAppLifecycleState(
AppLifecycleState state) → void -
Called when the system puts the app in the background or returns
the app to the foreground.
override
-
didChangeDependencies(
) → void -
Called when a dependency of this State object changes.
inherited
-
didChangeLocales(
List< Locale> ? locales) → void -
Called when the system tells the app that the user's locale has
changed. For example, if the user changes the system language
settings.
inherited
-
didChangeMetrics(
) → void -
Called when the application's dimensions change. For example,
when a phone is rotated.
inherited
-
didChangePlatformBrightness(
) → void -
Called when the platform brightness changes.
inherited
-
didChangeTextScaleFactor(
) → void -
Called when the platform's text scale factor changes.
inherited
-
didChangeViewFocus(
ViewFocusEvent event) → void -
Called whenever the PlatformDispatcher receives a notification that the
focus state on a view has changed.
inherited
-
didHaveMemoryPressure(
) → void -
Called when the system is running low on memory.
inherited
-
didPopRoute(
) → Future< bool> -
Called when the system tells the app to pop the current route, such as
after a system back button press or back gesture.
inherited
-
didPushRoute(
String route) → Future< bool> -
Called when the host tells the application to push a new route onto the
navigator.
inherited
-
didPushRouteInformation(
RouteInformation routeInformation) → Future< bool> -
Called when the host tells the application to push a new
RouteInformation and a restoration state onto the router.
inherited
-
didRequestAppExit(
) → Future< AppExitResponse> -
Called when a request is received from the system to exit the application.
inherited
-
didUpdateWidget(
covariant Camera oldWidget) → void -
Called whenever the widget configuration changes.
inherited
-
dispose(
) → void -
Called when this object is removed from the tree permanently.
override
-
formatDuration(
int seconds) → String -
fullImagePreview(
) → Widget -
getAssistAngleMessage(
) → String -
getAssistSpeedMessage(
) → String -
handleCancelBackGesture(
) → void -
Called when a predictive back gesture is canceled, indicating that no
navigation should occur.
inherited
-
handleCommitBackGesture(
) → void -
Called when a predictive back gesture is finished successfully, indicating
that the current route should be popped.
inherited
-
handleStartBackGesture(
PredictiveBackEvent backEvent) → bool -
Called at the start of a predictive back gesture.
inherited
-
handleStatusBarTap(
) → void -
Called when the user taps the status bar on iOS, to scroll a scroll
view to the top.
inherited
-
handleUpdateBackGestureProgress(
PredictiveBackEvent backEvent) → void -
Called when a predictive back gesture moves.
inherited
-
imagePreviewButton(
) → Widget -
initAccelerometerSub(
) → void -
initAutoCapture(
) → void -
initCameras(
) → void -
initGeoLocator(
) → Future< void> -
initPageController(
) → void -
initState(
) → void -
Called when this object is inserted into the tree.
override
-
mediaThumbnail(
{bool isBorderView = false}) → Widget -
nextButton(
{required String buttontitle, String? imagelength, void onTap()?}) → Widget -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onViewFinderTap(
TapUpDetails details, BoxConstraints constraints) → void -
permissionDeniedView(
) → Widget -
reassemble(
) → void -
Called whenever the application is reassembled during debugging, for
example during hot reload.
inherited
-
resolveStylesIfUnresolved(
BuildContext context) → void -
inherited
-
selectImage(
) → void -
setCamera(
{CameraDescription? cameraDescription}) → Future< void> -
setCameraInit(
) → void -
setCameraMode(
) → void -
setState(
VoidCallback fn) → void -
Notify the framework that the internal state of this object has changed.
inherited
-
silderView(
) → Widget -
startLocationStream(
) → Future< void> -
startTimer(
) → void -
startVideoRecording(
) → Future< void> -
stopVideoRecording(
) → Future< File?> -
takeOverlayCapture(
) → Future< File?> -
takePicture(
) → Future< File?> -
timerWidget(
int sec) → Widget -
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited